import * as iam from '@aws-cdk/aws-iam';
import { Duration, Size } from '@aws-cdk/core';
import { Construct } from 'constructs';
/**
 * (experimental) Configure the data processor.
 *
 * @experimental
 */
export interface DataProcessorProps {
    /**
     * (experimental) The length of time Kinesis Data Firehose will buffer incoming data before calling the processor.
     *
     * s
     *
     * @default Duration.minutes(1)
     * @experimental
     */
    readonly bufferInterval?: Duration;
    /**
     * (experimental) The amount of incoming data Kinesis Data Firehose will buffer before calling the processor.
     *
     * @default Size.mebibytes(3)
     * @experimental
     */
    readonly bufferSize?: Size;
    /**
     * (experimental) The number of times Kinesis Data Firehose will retry the processor invocation after a failure due to network timeout or invocation limits.
     *
     * @default 3
     * @experimental
     */
    readonly retries?: number;
}
/**
 * (experimental) The key-value pair that identifies the underlying processor resource.
 *
 * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-kinesisfirehose-deliverystream-processorparameter.html
 * @experimental
 */
export interface DataProcessorIdentifier {
    /**
     * (experimental) The parameter name that corresponds to the processor resource's identifier.
     *
     * Must be an accepted value in `CfnDeliveryStream.ProcessoryParameterProperty.ParameterName`.
     *
     * @experimental
     */
    readonly parameterName: string;
    /**
     * (experimental) The identifier of the underlying processor resource.
     *
     * @experimental
     */
    readonly parameterValue: string;
}
/**
 * (experimental) The full configuration of a data processor.
 *
 * @experimental
 */
export interface DataProcessorConfig {
    /**
     * (experimental) The type of the underlying processor resource.
     *
     * Must be an accepted value in `CfnDeliveryStream.ProcessorProperty.Type`.
     *
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-kinesisfirehose-deliverystream-processor.html#cfn-kinesisfirehose-deliverystream-processor-type
     * @experimental
     * @example
     *
     * 'Lambda'
     */
    readonly processorType: string;
    /**
     * (experimental) The key-value pair that identifies the underlying processor resource.
     *
     * @experimental
     */
    readonly processorIdentifier: DataProcessorIdentifier;
}
/**
 * (experimental) Options when binding a DataProcessor to a delivery stream destination.
 *
 * @experimental
 */
export interface DataProcessorBindOptions {
    /**
     * (experimental) The IAM role assumed by Kinesis Data Firehose to write to the destination that this DataProcessor will bind to.
     *
     * @experimental
     */
    readonly role: iam.IRole;
}
/**
 * (experimental) A data processor that Kinesis Data Firehose will call to transform records before delivering data.
 *
 * @experimental
 */
export interface IDataProcessor {
    /**
     * (experimental) The constructor props of the DataProcessor.
     *
     * @experimental
     */
    readonly props: DataProcessorProps;
    /**
     * (experimental) Binds this processor to a destination of a delivery stream.
     *
     * Implementers should use this method to grant processor invocation permissions to the provided stream and return the
     * necessary configuration to register as a processor.
     *
     * @experimental
     */
    bind(scope: Construct, options: DataProcessorBindOptions): DataProcessorConfig;
}
